4.12. umbra.components.factory.componentsManagerUi.nodes — Umbra 1.0.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »

# 4.12. umbra.components.factory.componentsManagerUi.nodes

nodes.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `umbra.components.factory.componentsManagerUi.componentsManagerUi.ComponentsManagerUi` Component Interface class nodes.

Others:

## 4.12.1. Module Attributes

`umbra.components.factory.componentsManagerUi.nodes.` `LOGGER`

## 4.12.2. Classes

class `umbra.components.factory.componentsManagerUi.nodes.` `PathNode`(name=None, parent=None, children=None, roles=None, nodeFlags=33, attributesFlags=33, **kwargs)

  Bases: `umbra.ui.nodes.GraphModelNode`

  This class factory defines `umbra.components.factory.componentsManagerUi.componentsManagerUi.ComponentsManagerUi`
    Component Interface class Model path node.

  Parameters: | name – Node name. ( String ) parent – Node parent. ( GraphModelNode ) children – Children. ( List ) roles – Roles. ( Dictionary ) nodeFlags – Node flags. ( Integer ) attributesFlags – Attributes flags. ( Integer ) **kwargs – Keywords arguments. ( ** )

class `umbra.components.factory.componentsManagerUi.nodes.` `ComponentNode`(component, name=None, parent=None, children=None, roles=None, nodeFlags=33, attributesFlags=33, **kwargs)

  Bases: `umbra.ui.nodes.GraphModelNode`

  This class factory defines `umbra.components.factory.componentsManagerUi.componentsManagerUi.ComponentsManagerUi` Component Interface class Model component node.

  Parameters: | component – Component. ( Component / QWidgetComponent / QObjectComponent ) name – Node name. ( String ) parent – Node parent. ( GraphModelNode ) children – Children. ( List ) roles – Roles. ( Dictionary ) nodeFlags – Node flags. ( Integer ) attributesFlags – Attributes flags. ( Integer ) **kwargs – Keywords arguments. ( ** )

  `component`

    This method is the property for self.__component attribute.

    Returns: | self.__component. ( Component / QWidgetComponent / QObjectComponent )

  `toolTipText`

    This method is the property for self.__toolTipText attribute.

    Returns: | self.__toolTipText. ( String )

  `updateToolTip`()

    This method updates the node tooltip.

    Returns: | Method success. ( Boolean )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »